@@ -15,3 +15,11 @@ test_that("list_linux_subscriptions", {
 test_that("list_linux_subscriptions", {
   expect_error(svc$list_linux_subscriptions(MaxResults = 20), NA)
 })
+
+test_that("list_registered_subscription_providers", {
+  expect_error(svc$list_registered_subscription_providers(), NA)
+})
+
+test_that("list_registered_subscription_providers", {
+  expect_error(svc$list_registered_subscription_providers(MaxResults = 20), NA)
+})
